MethodChannelBeaconsFlutter class

An implementation of BeaconsFlutterPlatform that uses method channels.

Inheritance

Constructors

MethodChannelBeaconsFlutter()
Constructor that sets up the method call handler

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scanResults → Stream<Map<String, dynamic>>
Stream of scan results from native platform
no setteroverride

Methods

checkPermissions() → Future<bool>
Check if required permissions are granted
override
getPlatformVersion() → Future<String?>
Get platform version (legacy method)
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestPermissions() → Future<bool>
Request required permissions
override
startScan({List<String>? iBeaconUUIDs}) → Future<bool>
Start scanning for beacons
override
stopScan() → Future<bool>
Stop scanning for beacons
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited