BeaconsFlutterPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • BeaconsFlutterPlatform
Implementers

Constructors

BeaconsFlutterPlatform()
Constructs a BeaconsFlutterPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scanResults → Stream<Map<String, dynamic>>
Stream of scan results
no setter

Methods

checkPermissions() → Future<bool>
Check if required permissions are granted
getPlatformVersion() → Future<String?>
Get platform version (legacy method)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestPermissions() → Future<bool>
Request required permissions
startScan({List<String>? iBeaconUUIDs}) → Future<bool>
Start scanning for beacons
stopScan() → Future<bool>
Stop scanning for beacons
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ BeaconsFlutterPlatform
The default instance of BeaconsFlutterPlatform to use.
getter/setter pair